@@ -1,4 +1,5 @@
 package Mail::Audit;
+use 5.006;
 use strict;
 
 # $Id: /my/icg/mail-audit/trunk/lib/Mail/Audit.pm 22093 2006-06-05T03:36:12.885477Z rjbs  $
@@ -19,7 +20,7 @@ use constant REJECTED  => 100;
 use constant DEFERRED  => 75;
 use constant DELIVERED => 0;
 
-$Mail::Audit::VERSION = '2.222';
+$Mail::Audit::VERSION = '2.224';
 
 =head1 NAME
 
@@ -106,10 +107,11 @@ an C<accept()> is unsuccessful, the message will be saved to the C<emergency>
 mailbox instead.  If no C<emergency> mailbox is defined, messages will be
 deferred back to the MTA, where they will show up in your mailq.
 
-You may also specify C<< log => $logfile >> to write a debugging log; you can
-set the verbosity of the log with the C<loglevel> key, on a scale of 1 to 4. If
-you specify a log level without a log file, logging will be written to
-F<~/mail-audit.log>.
+You may also specify C<< log => $logfile >> to write a debugging log.  If you
+don't specify a log file, logs will be written to F<~/mail-audit.log>.   You
+can set the verbosity of the log with the C<loglevel> key.  A higher loglevel
+will result in more lines being logged.  The default level is 3.  To get all
+internally generated logs, log at level 5.  To get none, log at -1.  
 
 Usually, the delivery methods C<accept>, C<pipe>, and C<resend> are final;
 Mail::Audit will terminate when they are done.  If you specify C<< noexit => 1
